```R
##read micro -array
##Affymetrix
library(GEOquery)
library(AnnoProbe)
library(oligo)
library(pd.mogene.1.0.st.v1)
dir_cels="E:\\R language\\GSE_downlod\\GSE116917_RAW"
setwd(dir_cels)
celFiles <- list.files(path =dir_cels, full.names = F,pattern = "\\.CEL.gz$")
cel_files <- read.celfiles(celFiles)
#rma
eset <- oligo::rma(cel_files)
#get gene matrix
library(stringr)
exp <- exprs(eset)
colnames(exp) = str_extract(colnames(exp),"GSM\\d*")
library(AnnoProbe)
ids <- idmap("GPL20775",type = 'soft')
exprSet<-filterEM(exp,ids)


##Agilent
data <- read.maimages(raw_datas,
                   source="agilent", 
                   green.only=TRUE,
                   other.columns = "gIsWellAboveBG")

y <- limma::backgroundCorrect(data, method="normexp")
#y <- normalizeBetweenArrays(y, method="quantile")

Control <- y$genes$ControlType==1L;table(Control)
NoSymbol <- is.na(y$genes$ProbeName);
table(NoSymbol)
IsExpr <- rowSums(y$other$gIsWellAboveBG > 0) >= 5;table(IsExpr)
Isdup <- duplicated(y$genes$SystematicName);table(Isdup)
yfilt <- y[!Control & !NoSymbol & IsExpr & !Isdup, ]
dim(yfilt)
exp = yfilt@.Data[[1]]
id <- yfilt@.Data[[3]]
rownames(exp) <- id$GeneName

##Illumina
name <- c("ID_REF",paste0(rep(1:24,each=2),".",rep(c("Sample","Detection Pval"),24)))
##2.Modify the header
cc= read.table(file="./GSE36961_non-normalized.txt.gz",
               header = T,sep = "\t",quote = "",fill = T,check.names=F,
               comment.char = "#")
colnames(cc) <- name
cc[is.na(cc)]=0
write.table (cc,file ="test.txt", sep ="\t",quote =F)
cc <- cc[ , !apply(cc==0,2,all)]
library(limma)
x <- read.ilmn("./test.txt", 
               expr="Sample",          
               probeid = "ID_REF",other.columns="Detection Pval")
p <- x$other$Detection

#background correction and quantile normalizes
y <- neqc(x,detection.p="Detection Pval")
exp=y$E

```





```R
##pre-process
load("E:\\R language\\GSE_downlod\\all_GSE.Rdata")
name <- ls()
library(stringr)
Exp <- name[str_detect(name,"exp")]
Pd <- name[str_detect(name,regex("pd",ignore_case = T))]
name <- gsub("_exp","",Exp)
for (i in Exp) {
  exp <- get(i)
  #exp <- exp[,-1]
  gene <- rownames(exp)
  exp <- apply(exp,2,as.numeric)
  rownames(exp) <- gene
  assign(i,exp)
  print(i)
  
}

library(DMwR2)
library(mice)
for (i in 1:length(Exp)){
exp<- get(Exp[i])
if(anyNA(exp)){
exp<-exp[-manyNAs(exp,0.8),]
cat("before NA：",sum(!complete.cases(exp)),"\n")
knnOutput<-knnImputation(exp,
                         k = 10, scale = FALSE, meth = "weighAvg",
                         distData = NULL)
cat("after 缺失值",sum(!complete.cases(knnOutput)),"\n")
assign(Exp[i],knnOutput)
}
else{
  cat(Exp[i],"has no NAs","\n")
}}

#removed low expression 
for (i in 1:length(Exp)){
gdf <- get(Exp[i])
cat("before:",length(gdf[,1]),"\t")
gdf <- gdf[rowSums(gdf>=1) >=2,colSums(gdf>=1)>=2]
cat("after:",length(gdf[,1]),"\n")
#assign(Exp[i],gdf)
}

m <- c()
M <- c()
for (i in 1:length(Exp))
  {
  gdf <- get(Exp[i])
  #gdf <- as.matrix(gdf[,-1])
  m <- c(m,min(gdf))
  M <- c(M,max(gdf))
}
m
M

# log2 transformation
for (i in 1:length(Exp))
{
ex <- get(Exp[i])
qx <- as.numeric(quantile(ex, c(0., 0.25, 0.5, 0.75, 0.99, 1.0), na.rm=T))
LogC <- (qx[5] > 100) ||
  (qx[6]-qx[1] > 50 && qx[2] > 0)
if (LogC) {ex[which(ex <= 0)] <- 0
ex <- log2(ex+1)} 
cat(Exp[i],max(ex),min(ex),"\n")
assign(Exp[i],ex)
}



for (i in 1:length(Exp)){
  
  xGSE <- rownames(get(Pd[i]))
  yGSE <- colnames(get(Exp[i]))
  cat(Exp[i],all.equal(xGSE,yGSE),"\n")
}




##Get the platform annotation information
ID_tran <- function(GSEname){
  library(GEOquery)
  library(dplyr)
  library(stringr)
  library(tidyr)
  gset <- getGEO(GSEname, destdir=".",
                 AnnotGPL = F,  
                 getGPL = F)
  
  gpL <- gset[[1]]@annotation
  gpl <- getGEO(gpL,destdir = '.',getGPL=F)
  id_probe <- gpl@dataTable@table
  colname <- c(colnames(id_probe))
  name1 <-c("Gene Symbol","Symbol","GENE_SYMBOL","ILMN_Gene")
  if(any(name1%in%colname)){
    name <- c("ID",name1[(name1%in%colname)])
    id <- id_probe %>% dplyr::select(all_of(name))
    colnames(id) <- c("ID","gene")
    id <- id[!(id[,"gene"]== ""),]}else if("gene_assignment"%in%colname){
      name <- c("ID","gene_assignment")
      id <- id_probe %>% select(all_of(name))
      id<- separate(id, gene_assignment, into = c("col1", "gene", "col3"), sep = " // ")
      colnames(id) <- c("ID","gene")
      id <- na.omit(id)
      id <- id[!(id[,"gene"]== ""),]
    }
  return(id)
}


for(i in 1:length(Exp)){
    exp <- get(Exp[i])
    id  <- ID_tran(Exp[i])
    exprSet<-filterEM(exp,id)
    assign(Exp[i],exprSet)
}


```

