```R
#Data preprocessing
#human Microarray
#pd, clinical matrix; exp, Z expression matrix
#Tissue differences
set.seed(123)

#Set colors
library(ggsci)
color <- ggsci::pal_npg("nrc")(10)
mod <- model.matrix(~factor(pd$Tissue_char2))
expr_rbe <- removeBatchEffect(exp, batch = pd$Series_id, design = mod)
boxplot(t(df_umap), outline = FALSE, notch = TRUE, las = 2)  ## Boxplot
expr_rbe <- na.omit(expr_rbe)

#Tissue
df_umap <- data.frame(t(apply(t(expr_rbe), 1,
function(v) { (v - mean(v, na.rm = TRUE)) / sd(v, na.rm = TRUE) })),
stringsAsFactors = FALSE)

df_umap[is.na(df_umap)] <- 0

#UMAP analysis
library(umap)
df_tissue <- expr_rbe
umap <- umap(t(df_tissue), method = 'naive', n_neighbors = 10)

#Extract UMAP values for plotting
df1 <- data.frame(umap$layout)
Tissue_df1 <- cbind(df1, pd)  # Add label column
library(ggplot2)
colnames(Tissue_df1)[9] <- "Tissue"

ggplot(Tissue_df1, aes(x = X1, y = X2, color = Tissue)) +
stat_ellipse(type = "norm", level = 0.5, size = 0, alpha = 0.3, geom = "polygon",
aes(fill = Tissue, color = Tissue)) +
geom_point(size = 1.5) +
scale_fill_manual(values = c(color[1:3])) +
scale_color_manual(values = c(color[1:3])) +
xlab('UMAP1') + ylab('UMAP2') + theme_minimal() +
ggtitle("TISSUE LEVEL") +
labs(subtitle = "Micro-array human") +
theme( #legend.position = "none",
aspect.ratio = 1,
plot.title = element_text(face = "bold", color = "black", size = 30, hjust = 0, vjust = 0, angle = 360),
plot.subtitle = element_text(face = "bold", color = "black", size = 15, hjust = 0, vjust = 0, angle = 360),
axis.title.x = element_text(vjust = 1, face = "bold", size = 20),
axis.title.y = element_text(size = 20, face = "bold", color = "black"),
legend.title = element_text(size = 20, face = "bold"),
legend.key.size = unit(10, 'mm'),
legend.text = element_text(size = 15),
panel.border = element_rect(fill = NA, color = "black", linewidth = 2, linetype = "solid"),
axis.text.x = element_blank(),
axis.ticks.x = element_blank(),
axis.text.y = element_blank(),
axis.ticks.y = element_blank()
)


##healthy condition----
##Muscle tissue----
muscle_pd <- pd[pd$Tissue_char2=="Muscle",]
#muscle_pd <- muscle_pd[muscle_pd$Health_condition!="Chronic obstructive pulmonary disease",]
#muscle_pd <- muscle_pd[muscle_pd$Health_condition!="Type 1 diabete",]

muscle_exp <-exp[,rownames(muscle_pd)]
library(sva)
mod <- model.matrix(~factor(muscle_pd$Health_condition,levels = unique(muscle_pd$Health_condition)))

muscle_rbe <- limma::removeBatchEffect(muscle_exp, batch = factor(muscle_pd$Series_id,levels =unique(muscle_pd$Series_id) ), design=mod)

df_umap <- data.frame(t(apply(t(muscle_rbe),1,
                              function(v){(v-mean(v,na.rm=T))/sd(v,na.rm=T)})),
                      stringsAsFactors=F)

df_umap[is.na(df_umap)] <- 0
#UMAP 
umap <- umap(df_umap,method='naive',n_neighbors = 20)

#Extract UMAP values for plotting
df1 <- data.frame(umap$layout)

muscle_df1 <-cbind(df1,muscle_pd[rownames(df1),] )#加入lavle列
ggplot(muscle_df1,aes(x=X1, y=X2,color=Health_condition))+
  stat_ellipse(type = "norm",level = 0.8,size=0,alpha = 0.3,geom = "polygon",
               aes(fill=Health_condition,color=Health_condition))+
  geom_point(size=1.5)+scale_fill_manual(values = c(color[1:6]))+
  scale_color_manual(values = c(color[1:6]))+
  xlab('UMAP1')+ylab('UMAP2')+theme_test()+ggtitle("HEALTH CONDITION LEVEL")+
  labs(subtitle = "Micro-array human") +
  theme( #legend.position = "none",
    aspect.ratio=1,
    plot.title=element_text(face="bold", #字体
                            color="black", #颜色
                            size=30,  #大小
                            hjust=0, #位置
                            vjust=0,
                            angle=360), # 角度
    plot.subtitle = element_text(face="bold", #字体
                                 color="black", #颜色
                                 size=15,  #大小
                                 hjust=0, #位置
                                 vjust=0,
                                 angle=360), # 角度
    
    
    axis.title.x=element_text(vjust=1, 
                              face="bold",
                              size=20),  # X axis title
    
    axis.title.y=element_text(size=20,
                              face="bold", 
                              color = "black"), 
    legend.title = element_text(size=20,face = "bold"),
    legend.key.size = unit(10, 'mm'),
    legend.text = element_text(size=15),
    panel.border = element_rect(fill=NA,color="black", linewidth=2, linetype="solid"),
    axis.text.x=element_blank(),axis.ticks.x=element_blank(),
    axis.text.y=element_blank(),axis.ticks.y=element_blank())



##gender----
##Health people
pd3<- muscle_pd[muscle_pd$Health_condition=="Health",]
exp3 <- exp[,rownames(pd3)]
mod <- model.matrix(~factor(pd3$Gender))

rbe3 <- limma::removeBatchEffect(exp3, batch = pd3$Series_id, design=mod)

df_umap <- data.frame(t(apply(t(rbe3),1,
                              function(v){(v-mean(v,na.rm=T))/sd(v,na.rm=T)})),
                      stringsAsFactors=F)

df_umap[is.na(df_umap)] <- 0
#UMAP 
umap <- umap(df_umap,method='naive',n_neighbors = 10)

#Extract UMAP values for plotting
df1 <- data.frame(umap$layout)

gender_df1 <-cbind(df1,pd3)#加入lavle列
gender_df <- cbind(df,pd3[rownames(df),])

gender_df <- gender_df[(gender_df$X2>0&gender_df$Gender=="Male")|(gender_df$X2<0&gender_df$Gender=="Female"),]

ggplot(gender_df,aes(x=X1, y=X2,color=Gender))+
  stat_ellipse(type = "norm",level = 0.95,size=0,alpha = 0.3,geom = "polygon",
               aes(fill=Gender,color=Gender))+
  geom_point(size=1.5)+scale_fill_manual(values = c(color[1:6]))+
  scale_color_manual(values = c(color[1:6]))+
  xlab('UMAP1')+ylab('UMAP2')+theme_test()+ggtitle("Gender LEVEL")+
  labs(subtitle = "Micro-array human") +
  theme( #legend.position = "none",
    aspect.ratio=1,
    plot.title=element_text(face="bold", #字体
                            color="black", #颜色
                            size=30,  #大小
                            hjust=0, #位置
                            vjust=0,
                            angle=360), # 角度
    plot.subtitle = element_text(face="bold", #字体
                                 color="black", #颜色
                                 size=15,  #大小
                                 hjust=0, #位置
                                 vjust=0,
                                 angle=360), # 角度
    
    
    axis.title.x=element_text(vjust=1, 
                              face="bold",
                              size=20),  # X axis title
    
    axis.title.y=element_text(size=20,
                              face="bold", 
                              color = "black"), 
    legend.title = element_text(size=20,face = "bold"),
    legend.key.size = unit(10, 'mm'),
    legend.text = element_text(size=15),
    panel.border = element_rect(fill=NA,color="black", linewidth=2, linetype="solid"),
    axis.text.x=element_blank(),axis.ticks.x=element_blank(),
    axis.text.y=element_blank(),axis.ticks.y=element_blank())


##age----
pd4<-  pd3[pd3$Gender=="Male",]
pd4 <- pd4[pd4$Age_char2!="unknown",]
pd4 <- pd4[pd4$Tissue_char1=="Vastus lateralis muscle",]
exp4 <- exp[,rownames(pd4)]
table(pd4$Tissue_char1)
mod <- model.matrix(~factor(pd4$Age_char2))

rbe3 <- limma::removeBatchEffect(exp4, batch = pd4$Series_id,design = mod)

df_umap <- data.frame(t(apply(t(rbe3),1,
                              function(v){(v-mean(v,na.rm=T))/sd(v,na.rm=T)})),
                      stringsAsFactors=F)

df_umap[is.na(df_umap)] <- 0
#UMAP 
umap <- umap(df_umap,method='naive',n_neighbors = 10)

#Extract UMAP values for plotting
df1 <- data.frame(umap$layout)
df1 <-cbind(df1, pd4)

ggplot(df1,aes(x=X1, y=X2,color=Age_char2))+
  stat_ellipse(type = "norm",level = 0.95,size=0,alpha = 0.3,geom = "polygon",
               aes(fill=Age_char2,color=Age_char2 ))+
  geom_point(size=1.5)+scale_fill_manual(values = c(color[1:6]))+
  scale_color_manual(values = c(color[1:6]))+
  xlab('UMAP1')+ylab('UMAP2')+theme_test()+ggtitle("AGE LEVEL")+
  labs(subtitle = "Micro-array human") +
  theme( #legend.position = "none",
    aspect.ratio=1,
    plot.title=element_text(face="bold", 
                            color="black", 
                            size=30,  
                            hjust=0, 
                            vjust=0,
                            angle=360), 
    plot.subtitle = element_text(face="bold", 
                                 color="black",
                                 size=15, 
                                 hjust=0,
                                 vjust=0,
                                 angle=360), 
    
    
    axis.title.x=element_text(vjust=1, 
                              face="bold",
                              size=20),  # X axis title
    
    axis.title.y=element_text(size=20,
                              face="bold", 
                              color = "black"), 
    legend.title = element_text(size=20,face = "bold"),
    legend.key.size = unit(10, 'mm'),
    legend.text = element_text(size=15),
    panel.border = element_rect(fill=NA,color="black", linewidth=2, linetype="solid"),
    axis.text.x=element_blank(),axis.ticks.x=element_blank(),
    axis.text.y=element_blank(),axis.ticks.y=element_blank())


#Exercise group----
table(pd4$Age_char2)
pd5 <-  pd4[pd4$Age_char2=="Middle aged",]
exp5 <- exp[,rownames(pd5)]

mod <- model.matrix(~factor(pd5$Group))

rbe3 <- limma::removeBatchEffect(exp5, batch = pd5$Series_id,design = mod)

df_umap <- data.frame(t(apply(t(rbe3),1,
                              function(v){(v-mean(v,na.rm=T))/sd(v,na.rm=T)})),
                      stringsAsFactors=F)

df_umap[is.na(df_umap)] <- 0
#UMAP
umap <- umap(df_umap,method='naive',n_neighbors = 10)

#Extract UMAP values for plotting
df1 <- data.frame(umap$layout)
df1 <-cbind(df1, pd5 )
df1$all <- paste0(df1$Exe_time,df1$Exe_Intensity,df1$Exe_Type,df1$Exe_Modality)
ggplot(df1,aes(x=X1, y=X2,color=Group))+
  stat_ellipse(type = "norm",level = 0.9,size=0,alpha = 0.3,geom = "polygon",
               aes(fill=Group,color=Group))+
  geom_point(size=1.5)+scale_fill_manual(values = c(color[1:6]))+
  scale_color_manual(values = c(color[1:6]))+
  xlab('UMAP1')+ylab('UMAP2')+theme_test()+ggtitle("Exercise LEVEL")+
  labs(subtitle = "Micro-array human") +
  theme( #legend.position = "none",
    aspect.ratio=1,
    plot.title=element_text(face="bold", 
                            color="black", 
                            size=30,  
                            vjust=0,
                            angle=360),
    plot.subtitle = element_text(face="bold", 
                                 color="black", 
                                 size=15, 
                                 hjust=0, 
                                 vjust=0,
                                 angle=360), 
    
    axis.title.x=element_text(vjust=1, 
                              face="bold",
                              size=20),  # X axis title
    
    axis.title.y=element_text(size=20,
                              face="bold", 
                              color = "black"), 
    legend.title = element_text(size=20,face = "bold"),
    legend.key.size = unit(10, 'mm'),
    legend.text = element_text(size=15),
    panel.border = element_rect(fill=NA,color="black", linewidth=2, linetype="solid"),
    axis.text.x=element_blank(),axis.ticks.x=element_blank(),
    axis.text.y=element_blank(),axis.ticks.y=element_blank())


```

