```R
# gender----
# Initialize gender_df with empty data frame
gender_df <- data.frame(
  Gene = character(),
  gene_p = numeric(),
  ex_p = numeric(),
  interact_p = numeric(),
  stringsAsFactors = FALSE
)

# Assuming `rbe` is the data frame containing relevant data, adjust as needed
raw <- t(rbe[, gender$GSM])

# Loop through each gene
for (i in 1:ncol(raw)) {
  current_raw_var <- current_raw_var-mean(raw[, i])
  # Assuming `dljdz` is a function to process `current_raw_var`
  
  # Construct the data frame for modeling
  rbe_var <- data.frame(
    gene = current_raw_var,
    batch = factor(gender$GSE, levels = unique(gender$GSE)),
    tissue = factor(gender$tissue, levels = unique(gender$tissue)),
    age = factor(gender$age),
    ex = factor(gender$ex, levels = c("Sedentary", "Exercise")),
    gender = factor(gender$gender, levels = c("Female", "Male"))
  )
  
  # Try fitting the model
  mod <- tryCatch(
    {
      glmer(gender ~ gene + tissue + ex+ex:gene + (1 | batch), data = rbe_var, family = binomial)
    },
    warning = function(w) {
      message("Warning occurred: ", conditionMessage(w))
      return(NULL)  # Return NULL to indicate model fitting failure
    }
  )
  
  if (!is.null(mod)) {
    # If the model successfully fits, proceed to extract and store required items
    tryCatch(
      {
        gene_p.value <- Anova(mod)["gene", "Pr(>Chisq)"]
        ex_p.value <- Anova(mod)["ex", "Pr(>Chisq)"]
        interact_p.value <- Anova(mod)["gene:ex", "Pr(>Chisq)"]
        
        # Store results in gender_df
        gender_df[i, "Gene"] <- colnames(raw)[i]
        gender_df[i, "gene_p"] <- gene_p.value
        gender_df[i, "ex_p"] <- ex_p.value
        gender_df[i, "interact_p"] <- interact_p.value  # Placeholder for interact_p, assuming you want it to be NA initially
      },
      warning = function(w) {
        message("Warning occurred during Anova or data assignment: ", conditionMessage(w))
        # Set relevant values to NA
        gender_df[i, "Gene"] <- colnames(raw)[i]
        gender_df[i, "gene_p"] <- NA
        gender_df[i, "ex_p"] <- NA
        gender_df[i, "interact_p"] <- NA
      }
    )
  } else {
    # If the model fitting fails, set relevant values to NA
    gender_df[i, "Gene"] <- colnames(raw)[i]
    gender_df[i, "gene_p"] <- NA
    gender_df[i, "ex_p"] <- NA
    gender_df[i, "interact_p"] <- NA
  }
}

# Print the results
print(gender_df)


##BMI----
BMI <- as.data.frame(cbind(pd$Sample_id,pd$Series_id,
                           pd$BMI_char1,pd$Tissue_char2,
                           pd$Health_condition,
                           pd$Age_char2,pd$Group,pd$Gender))
colnames(BMI) <- c("GSM","GSE","bmi","tissue","health","age","ex","gender")
library(stringr)
BMI <- BMI[!(str_detect(BMI$bmi,"Mean")|str_detect(BMI$bmi,"~")),]
BMI <- BMI[BMI$bmi!="unknown",]
raw <- t(rbe[,BMI$GSM])

table(BMI$health)
  
# Initialize BMI_df with empty data frame
BMI_df <- data.frame(
  Gene = character(),
  gene_p = numeric(),
  ex_p = numeric(),
  interact_p = numeric(),  # Adding interact_p column
  stringsAsFactors = FALSE
)

# Loop through each gene
for (i in seq_along(colnames(raw))) {
  
  # Extract current variable, BMI$bmi, and BMI$GSE
  current_raw_var <- raw[, i]
  current_raw_var <- current_raw_var-mean(raw[, i])
  rbe_var <- data.frame(
    gene = current_raw_var,
    bmi = as.numeric(BMI$bmi),
    batch = as.factor(BMI$GSE),
    tissue = as.factor(BMI$tissue),
    ex = factor(BMI$ex, level = c("Sedentary", "Exercise"))
  )
  
  # Try fitting the model
  mod <- tryCatch(
    {
      lme(bmi ~ gene + ex:gene + ex, random = ~1|batch, data = rbe_var)
    },
    warning = function(w) {
      message("Warning occurred: ", conditionMessage(w))
      return(NULL)  # Return NULL to indicate model fitting failure
    }
  )
  
  if (!is.null(mod)) {
    # If the model successfully fits, proceed to extract and store required items
    tryCatch(
      {
        gene_p.value <- Anova(mod)["gene", "Pr(>Chisq)"]
        ex_p.value <- Anova(mod)["ex", "Pr(>Chisq)"]
        interact_p.value <- Anova(mod)["gene:ex", "Pr(>Chisq)"]
        
        # Store results in BMI_df
        BMI_df[i, "Gene"] <- colnames(raw)[i]
        BMI_df[i, "gene_p"] <- gene_p.value
        BMI_df[i, "ex_p"] <- ex_p.value
        BMI_df[i, "interact_p"] <- interact_p.value  # Corrected column name
      },
      warning = function(w) {
        message("Warning occurred during Anova or data assignment: ", conditionMessage(w))
        # Set relevant values to NA
        BMI_df[i, "Gene"] <- colnames(raw)[i]
        BMI_df[i, "gene_p"] <- NA
        BMI_df[i, "ex_p"] <- NA
        BMI_df[i, "interact_p"] <- NA  # Ensure to set interact_p to NA on warning
      }
    )
  } else {
    # If the model fitting fails, set relevant values to NA
    BMI_df[i, "Gene"] <- colnames(raw)[i]
    BMI_df[i, "gene_p"] <- NA
    BMI_df[i, "ex_p"] <- NA
    BMI_df[i, "interact_p"] <- NA
  }
}

# Print the results
print(BMI_df)



##age----
# Initialize age_df with empty data frame
age_df <- data.frame(
  Gene = character(),
  gene_p = numeric(),
  ex_p = numeric(),
  interact_p=numeric(),
  stringsAsFactors = FALSE
)
raw <- t(rbe[,age$GSM])


# Loop through each gene
for (i in seq_along(colnames(raw))) {
  
  # Extract current variable, BMI$bmi, and BMI$GSE
  current_raw_var <- raw[, i] - mean(raw[, i])  # Centering the variable
  rbe_var <- data.frame(
    gene = current_raw_var,
    batch = as.factor(age$GSE),
    tissue = as.factor(age$tissue),
    gender = as.factor(age$gender),
    ex = factor(age$ex, level = c("Sedentary", "Exercise")),
    age = as.numeric(age$age)
  )
  
  # Try fitting the model
  mod <- tryCatch(
    {
      lme(age ~ gene + tissue + gender + ex + ex:gene, random = ~1|batch, data = rbe_var)
    },
    warning = function(w) {
      message("Warning occurred: ", conditionMessage(w))
      return(NULL)  # Return NULL to indicate model fitting failure
    }
  )
  
  if (!is.null(mod)) {
    # If the model successfully fits, proceed to extract and store required items
    tryCatch(
      {
        gene_p.value <- Anova(mod)["gene", "Pr(>Chisq)"]
        ex_p.value <- Anova(mod)["ex", "Pr(>Chisq)"]
        interact_p.value <- Anova(mod)["gene:ex", "Pr(>Chisq)"]
        
        # Store results in age_df
        age_df[i, "Gene"] <- colnames(raw)[i]
        age_df[i, "gene_p"] <- gene_p.value
        age_df[i, "ex_p"] <- ex_p.value
        age_df[i, "interact_p"] <- interact_p.value  # Corrected column name
      },
      warning = function(w) {
        message("Warning occurred during Anova or data assignment: ", conditionMessage(w))
        # Set relevant values to NA
        age_df[i, "Gene"] <- colnames(raw)[i]
        age_df[i, "gene_p"] <- NA
        age_df[i, "ex_p"] <- NA
        age_df[i, "interact_p"] <- NA  # Ensure to set interact_p to NA on warning
      }
    )
  } else {
    # If the model fitting fails, set relevant values to NA
    age_df[i, "Gene"] <- colnames(raw)[i]
    age_df[i, "gene_p"] <- NA
    age_df[i, "ex_p"] <- NA
    age_df[i, "interact_p"] <- NA
  }
}

# Print the results
print(age_df)





new_BMI_df <- BMI_df[BMI_df$gene_p<0.05|BMI_df$interact_p<0.05,]
gender_df <- na.omit(gender_df)
new_gender_df <- gender_df[gender_df$gene_p<0.05|gender_df$interact_p<0.05,]
new_age_df <- age_df[age_df$gene_p<0.05|age_df$interact_p<0.05,]

##gene annotation
library(AnnotationDbi)
library(org.Hs.eg.db)


gene_name <- BMI_df$Gene[1]
suppressMessages(org.Hs.eg.db)
columns(org.Hs.eg.db)
library(clusterProfiler)

go_terms <- select(org.Hs.eg.db, keys = gene_name, keytype = "SYMBOL", columns = c("GOALL"))
ALL <- enrichGO(gene_name, "org.Hs.eg.db", keyType = "SYMBOL",ont = 'MF',pvalueCutoff  = 0.05,pAdjustMethod = "BH",  qvalueCutoff  = 0.1, readable=T)
x <- ALL@result

print(go_terms)

library(clusterProfiler)

new_age_df$Function <- NA
for (i in 1:length(new_age_df$Gene)) {
  gene_name <- new_age_df[i, "Gene"]  # Assuming 'Gene' column contains gene symbols
  function_gene <- enrichGO(gene_name, "org.Hs.eg.db", keyType = "SYMBOL", ont = 'MF',
                            pvalueCutoff = 0.05, pAdjustMethod = "BH", qvalueCutoff = 0.1, readable = TRUE)
  
  # Extract and concatenate descriptions
  
  if (length(function_gene)> 0) {
    x <- function_gene@result
    result <- paste0(x$Description, collapse = ";")
    new_age_df[i, "Function"] <- result
  } else {
    new_age_df[i, "Function"] <- NA  # Handle case where no enrichment result is found
  }
}


new_BMI_df$Function <- NA
for (i in 1:length(new_BMI_df$Gene)) {
  gene_name <- new_BMI_df[i, "Gene"]  # Assuming 'Gene' column contains gene symbols
  function_gene <- enrichGO(gene_name, "org.Hs.eg.db", keyType = "SYMBOL", ont = 'MF',
                            pvalueCutoff = 0.05, pAdjustMethod = "BH", qvalueCutoff = 0.1, readable = TRUE)
  
  # Extract and concatenate descriptions
  
  if (length(function_gene)> 0) {
    x <- function_gene@result
    result <- paste0(x$Description, collapse = ";")
    new_BMI_df[i, "Function"] <- result
  } else {
    new_BMI_df[i, "Function"] <- NA  # Handle case where no enrichment result is found
  }
}


new_gender_df$Function <- NA
for (i in 1:length(new_gender_df$Gene)) {
  gene_name <- new_gender_df[i, "Gene"]  # Assuming 'Gene' column contains gene symbols
  function_gene <- enrichGO(gene_name, "org.Hs.eg.db", keyType = "SYMBOL", ont = 'MF',
                            pvalueCutoff = 0.05, pAdjustMethod = "BH", qvalueCutoff = 0.1, readable = TRUE)
  
  # Extract and concatenate descriptions
  
  if (length(function_gene)> 0) {
    x <- function_gene@result
    result <- paste0(x$Description, collapse = ";")
    new_gender_df[i, "Function"] <- result
  } else {
    new_gender_df[i, "Function"] <- NA  # Handle case where no enrichment result is found
  }
}


gene_symbols <- new_gender_df$Gene

# Get gene annotations from org.Hs.eg.db
gene_annotations <- AnnotationDbi::select(org.Hs.eg.db, 
                           keys = gene_symbols, 
                           columns = c("ENTREZID", "GENENAME", "ENSEMBL"),
                           keytype = "SYMBOL")
x <- gene_annotations[match(new_gender_df$Gene,gene_annotations$SYMBOL),]
all.equal(x$SYMBOL,new_gender_df$Gene)
cc <- cbind(x,new_gender_df[,-1])
cc$Species <- "Homo sapiens"
colnames(cc) <- c("SYMBOL"  ,"ENTREZID" ,"GENENAME" ,"ENSEMBL"  ,
                  "Gender_Related_P.value " , "Exercise_Related_P.value" , "Interaction_effect_P.value", "Function","Species")

new_gender_df <- cc

##age----
gene_symbols <- new_age_df$Gene
gene_annotations <- AnnotationDbi::select(org.Hs.eg.db, 
                                          keys = gene_symbols, 
                                          columns = c("ENTREZID", "GENENAME", "ENSEMBL"),
                                          keytype = "SYMBOL")
x <- gene_annotations[match(new_age_df$Gene,gene_annotations$SYMBOL),]
all.equal(x$SYMBOL,new_age_df$Gene)
cc <- cbind(x,new_age_df[,-1])
cc$Species <- "Homo sapiens"
colnames(cc) <- c("SYMBOL"  ,"ENTREZID" ,"GENENAME" ,"ENSEMBL"  ,
                  "Age_Related_P.value " , "Exercise_Related_P.value" , "Interaction_effect_P.value", "Function","Species")

new_age_df <- cc

##BMI----
gene_symbols <- new_BMI_df$Gene
gene_annotations <- AnnotationDbi::select(org.Hs.eg.db, 
                                          keys = gene_symbols, 
                                          columns = c("ENTREZID", "GENENAME", "ENSEMBL"),
                                          keytype = "SYMBOL")
x <- gene_annotations[match(new_BMI_df$Gene,gene_annotations$SYMBOL),]
all.equal(x$SYMBOL,new_BMI_df$Gene)
cc <- cbind(x,new_BMI_df[,-1])
cc$Species <- "Homo sapiens"
colnames(cc) <- c("SYMBOL"  ,"ENTREZID" ,"GENENAME" ,"ENSEMBL"  ,
                  "BMI_Related_P.value " , "Exercise_Regulated_P.value" ,  "Function","Species")

new_BMI_df <- cc


```

