```R
##Human
#RNA -seq mRNA
# load data
load("~/exedatabase_v1.5/human_mRNA.RData")
load("~/exedatabase_v1.5/all_pd.RData")
.libPaths(c('~/R/x86_64-pc-linux-gnu-library/4.2',
            '/home/data/refdir/Rlib',
            '/usr/local/lib/R/library'))
library(stringr)
library(limma)

mrna_human.pd$label_tec <- paste0(mrna_human.pd$SeqTech,mrna_human.pd$SeqType,mrna_human.pd$Series_id)
mrna_human.pd$label_cli <- paste0(mrna_human.pd$Tissue_char1,mrna_human.pd$Age_char2,mrna_human.pd$BMI_char2,
                                   mrna_human.pd$Gender,mrna_human.pd$Health_condition,mrna_human.pd$Other_treatment)
mrna_human.pd$label_exe <- paste0(mrna_human.pd$Exe_time,mrna_human.pd$Exe_Duration,
                                   mrna_human.pd$Exe_Freq,mrna_human.pd$Exe_Intensity,
                                   mrna_human.pd$Exe_Modality,mrna_human.pd$Exe_Type,mrna_human.pd$Exe_pattern,mrna_human.pd$Sampling_time)

exp.file <- ls()[str_detect(ls(),"mRNA")][str_detect(ls()[str_detect(ls(),"mRNA")],"GSE")]
exp.file <- setdiff(exp.file,c("GSE163356_mRNA","GSE106865_mRNA",
                               "GSE28422_mRNA","GSE224310_mRNA"))
all.out.table <- data.frame(Gene_Symbol = 1,Average_expression = 1,logFC = 1,P.Value = 1,adj.P.Value = 1,
                            Series_id = 1,Tissue_char1 = 1,Tissue_char2 = 1,Age = 1,
                            Gender = 1,Health_condition = 1,BMI = 1,
                            Exercise_pattern = 1,Exercise_type = 1,
                            Exercise_during = 1,Exercise_frequency = 1,
                            Exercise_time = 1,Exercise_intensity = 1,Sampling_time = 1)



used.sample <- c()
for (i in exp.file) {
  exp <- get(i)
  common_sample <- intersect(colnames(exp),rownames(mrna_human.pd))
  pd <- mrna_human.pd[common_sample,]
  exp <- exp[,common_sample]
 
  sed.pd <- subset(pd,Group == "Sedentary")
  exe.pd <- subset(pd,Group == "Exercise")
  sed.pd$label <- paste0(sed.pd$label_tec,sed.pd$label_cli,sed.pd$label_exe)
  exe.pd$label <- paste0(exe.pd$label_tec,exe.pd$label_cli,exe.pd$label_exe)
 
  for (j in unique(exe.pd$label)) {
    sub.exe <- subset(exe.pd,label == j)
    sub.sed <- subset(sed.pd,label_cli == unique(sub.exe$label_cli) & label_tec == unique(sub.exe$label_tec))

    if (length(sub.exe$label) > 2 & length(sub.exe$label) > 2) {
      EXP <- exp[,c(rownames(sub.exe),rownames(sub.sed))]
      GROUP <- rep(c("Exercise","Sedentary"),
                   c(length(rownames(sub.exe)),length(rownames(sub.sed))))
      # DEG analysis
      design <- model.matrix(~0+factor(GROUP))
      colnames(design)=levels(factor(GROUP))
      rownames(design)=colnames(EXP)
      EXP <- calcNormFactors(EXP)
      EXP <- voom(EXP,design,plot = T)
      contrast.matrix<-makeContrasts(paste0(c("Exercise","Sedentary"),collapse = "-"),levels = design)
      contrast.matrix
      fit <- lmFit(EXP,design)
      fit2 <- contrasts.fit(fit, contrast.matrix)
      fit2 <- eBayes(fit2)
      tempOutput = topTable(fit2, coef=1, n=Inf)
      DEG = na.omit(tempOutput)
      
      out.table <- data.frame(Gene_Symbol = rownames(DEG),Average_expression = DEG$AveExpr,logFC = DEG$logFC,P.Value = DEG$P.Value,adj.P.Value = DEG$adj.P.Val,
                              Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                              Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                              Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                              Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                              Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))
      
      all.out.table <- rbind(all.out.table,out.table)
      used.sample <- c(used.sample,colnames(EXP))
    }else{
      print(paste0(i,"has a wrong group:",j))
    }
  }
}
all.out.table <- all.out.table[-1,]

# 复杂数据逐个差异分析
new.pd <- subset(mrna_human.pd,Series_id %in% c("GSE163356","GSE106865","GSE28422","GSE224310"))

DEG <- function(EXP,GROUP){
  library(limma)
  design <- model.matrix(~0+factor(GROUP))
  colnames(design)=levels(factor(GROUP))
  rownames(design)=colnames(EXP)
  EXP <- calcNormFactors(EXP)
  EXP <- voom(EXP,design,plot = T)
  contrast.matrix<-makeContrasts(paste0(c("Exercise","Sedentary"),collapse = "-"),levels = design)
  contrast.matrix
  fit <- lmFit(EXP,design)
  fit2 <- contrasts.fit(fit, contrast.matrix)
  fit2 <- eBayes(fit2)
  tempOutput = topTable(fit2, coef=1, n=Inf)
  DEG = na.omit(tempOutput)
  return(DEG)
}

exp <- get(c("GSE163356_mRNA","GSE106865_mRNA","GSE28422_mRNA","GSE224310_mRNA")[1])
pd <- new.pd[colnames(exp),]

group <- subset(pd,Other_treatment == "Untrained")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table1 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table2 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,!(Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table3 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = "One bout exercise after adaptive training",Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


exp <- get(c("GSE163356_mRNA","GSE106865_mRNA","GSE28422_mRNA","GSE224310_mRNA")[2])
pd <- new.pd[colnames(exp),]

group <- subset(pd,Other_treatment == "Untrained")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table4 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- rbind(subset(pd,Exe_pattern == "Continuouse exercise/Exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
exp1 <- calcNormFactors(exp1)
exp1 <- voom(EXP,design,plot = T)
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table5 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,!(Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table6 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))



exp <- get(c("GSE163356_mRNA","GSE106865_mRNA","GSE28422_mRNA","GSE224310_mRNA")[3])
pd <- new.pd[colnames(exp),]

group <- subset(pd,Other_treatment == "Untrained" & Gender == "Male" & Age_char2 =="Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table7 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,Other_treatment == "Untrained" & Gender == "Female" & Age_char2 =="Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table8 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


group <- subset(pd,Other_treatment == "Untrained" & Gender == "Male" & Age_char2 =="Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table9 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,Other_treatment == "Untrained" & Gender == "Female" & Age_char2 =="Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table10 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Male" & group$Age_char2 == "Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table11 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Female" & group$Age_char2 == "Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table12 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))




group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Male" & group$Age_char2 == "Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table13 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Female" & group$Age_char2 == "Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table14 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))



group <- subset(pd,!(Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Female" & group$Age_char2 == "Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table15 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,!(Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Male" & group$Age_char2 == "Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table16 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


group <- subset(pd,!(Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Female" & group$Age_char2 == "Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table17 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,!(Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Male" & group$Age_char2 == "Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table18 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


exp <- get(c("GSE163356_mRNA","GSE106865_mRNA","GSE28422_mRNA","GSE224310_mRNA")[4])
pd <- new.pd[colnames(exp),]

group <- subset(pd,Other_treatment == "Untrained")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table19 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


group <- subset(pd,!(Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table20 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "One bout exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


for (i in 1:(length(exp.file)+4)) {
  nnn <- get(paste0("out.table",i))
  all.out.table <- rbind(all.out.table,nnn)
}

human.deg <- all.out.table
mrna_human.pd <- rbind(mrna_human.pd[unique(used.sample),],new.pd)

# save(mrna_human.pd,file = "~/exedatabase_v1.5/mrna_human_pd.RData")
# save(human.deg,file = "~/exedatabase_v1.5/mrna_human_deg.RData")
 
```

```R
##RNA-seq ncRNA
#load data 
load("~/exedatabase_v1.5/human_ncRNA.RData")
load("~/exedatabase_v1.5/all_pd.RData")
.libPaths(c('~/R/x86_64-pc-linux-gnu-library/4.2',
            '/home/data/refdir/Rlib',
            '/usr/local/lib/R/library'))
library(stringr)
library(limma)

ncrna_human.pd$label_tec <- paste0(ncrna_human.pd$SeqTech,ncrna_human.pd$SeqType,ncrna_human.pd$Series_id)
ncrna_human.pd$label_cli <- paste0(ncrna_human.pd$Tissue_char1,ncrna_human.pd$Age_char2,ncrna_human.pd$BMI_char2,
                             ncrna_human.pd$Gender,ncrna_human.pd$Health_condition,ncrna_human.pd$Other_treatment)
ncrna_human.pd$label_exe <- paste0(ncrna_human.pd$Exe_time,ncrna_human.pd$Exe_Duration,
                             ncrna_human.pd$Exe_Freq,ncrna_human.pd$Exe_Intensity,
                             ncrna_human.pd$Exe_Modality,ncrna_human.pd$Exe_Type,ncrna_human.pd$Exe_pattern,ncrna_human.pd$Sampling_time)
# 逐个进行差异分析
exp.file <- ls()[str_detect(ls(),"ncRNA")][str_detect(ls()[str_detect(ls(),"ncRNA")],"GSE")]
exp.file <- setdiff(exp.file,c("GSE163356_ncRNA","GSE106865_ncRNA",
                               "GSE28422_ncRNA","GSE224310_ncRNA"))
all.out.table <- data.frame(Gene_Symbol = 1,Average_expression = 1,logFC = 1,P.Value = 1,adj.P.Value = 1,
                            Series_id = 1,Tissue_char1 = 1,Tissue_char2 = 1,Age = 1,
                            Gender = 1,Health_condition = 1,BMI = 1,
                            Exercise_pattern = 1,Exercise_type = 1,
                            Exercise_during = 1,Exercise_frequency = 1,
                            Exercise_time = 1,Exercise_intensity = 1,Sampling_time = 1)



used.sample <- c()
for (i in exp.file) {
  exp <- get(i)
  common_sample <- intersect(colnames(exp),rownames(ncrna_human.pd))
  pd <- ncrna_human.pd[common_sample,]
  exp <- exp[,common_sample]

  sed.pd <- subset(pd,Group == "Sedentary")
  exe.pd <- subset(pd,Group == "Exercise")
  sed.pd$label <- paste0(sed.pd$label_tec,sed.pd$label_cli,sed.pd$label_exe)
  exe.pd$label <- paste0(exe.pd$label_tec,exe.pd$label_cli,exe.pd$label_exe)
  

  for (j in unique(exe.pd$label)) {
    sub.exe <- subset(exe.pd,label == j)

    sub.sed <- subset(sed.pd,label_cli == unique(sub.exe$label_cli) & label_tec ==   unique(sub.exe$label_tec))

    if (length(sub.exe$label) > 2 & length(sub.exe$label) > 2) {
      EXP <- exp[,c(rownames(sub.exe),rownames(sub.sed))]
      GROUP <- rep(c("Exercise","Sedentary"),
                   c(length(rownames(sub.exe)),length(rownames(sub.sed))))
      # DEG analysis
      design <- model.matrix(~0+factor(GROUP))
      colnames(design)=levels(factor(GROUP))
      rownames(design)=colnames(EXP)
      EXP <- calcNormFactors(EXP)
      EXP <- voom(EXP,design,plot = T)
      contrast.matrix<-makeContrasts(paste0(c("Exercise","Sedentary"),collapse = "-"),levels = design)
      contrast.matrix
      fit <- lmFit(EXP,design)
      fit2 <- contrasts.fit(fit, contrast.matrix)
      fit2 <- eBayes(fit2)
      tempOutput = topTable(fit2, coef=1, n=Inf)
      DEG = na.omit(tempOutput)

      out.table <- data.frame(Gene_Symbol = rownames(DEG),Average_expression = DEG$AveExpr,logFC = DEG$logFC,P.Value = DEG$P.Value,adj.P.Value = DEG$adj.P.Val,
                              Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                              Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                              Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                              Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                              Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))
      
      all.out.table <- rbind(all.out.table,out.table)
      used.sample <- c(used.sample,colnames(EXP))
    }else{
      print(paste0(i,"has a wrong group:",j))
    }
  }
}
all.out.table <- all.out.table[-1,]

# 复杂数据逐个差异分析
new.pd <- subset(ncrna_human.pd,Series_id %in% c("GSE163356","GSE106865","GSE28422","GSE224310"))

DEG <- function(EXP,GROUP){
  library(limma)
  design <- model.matrix(~0+factor(GROUP))
  colnames(design)=levels(factor(GROUP))
  rownames(design)=colnames(EXP)
  EXP <- calcNormFactors(EXP)
  EXP <- voom(EXP,design,plot = T)
  contrast.matrix<-makeContrasts(paste0(c("Exercise","Sedentary"),collapse = "-"),levels = design)
  contrast.matrix
  fit <- lmFit(EXP,design)
  fit2 <- contrasts.fit(fit, contrast.matrix)
  fit2 <- eBayes(fit2)
  tempOutput = topTable(fit2, coef=1, n=Inf)
  DEG = na.omit(tempOutput)
  return(DEG)
}

exp <- get(c("GSE163356_ncRNA","GSE106865_ncRNA","GSE28422_ncRNA","GSE224310_ncRNA")[1])
pd <- new.pd[colnames(exp),]

group <- subset(pd,Other_treatment == "Untrained")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table1 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table2 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,!(Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table3 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = "One bout exercise after adaptive training",Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


exp <- get(c("GSE163356_ncRNA","GSE106865_ncRNA","GSE28422_ncRNA","GSE224310_ncRNA")[2])
pd <- new.pd[colnames(exp),]

group <- subset(pd,Other_treatment == "Untrained")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table4 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- rbind(subset(pd,Exe_pattern == "Continuouse exercise/Exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table5 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,!(Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table6 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))



exp <- get(c("GSE163356_ncRNA","GSE106865_ncRNA","GSE28422_ncRNA","GSE224310_ncRNA")[3])
pd <- new.pd[colnames(exp),]

group <- subset(pd,Other_treatment == "Untrained" & Gender == "Male" & Age_char2 =="Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table7 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,Other_treatment == "Untrained" & Gender == "Female" & Age_char2 =="Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table8 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


group <- subset(pd,Other_treatment == "Untrained" & Gender == "Male" & Age_char2 =="Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table9 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                         Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                         Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                         Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                         Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                         Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,Other_treatment == "Untrained" & Gender == "Female" & Age_char2 =="Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table10 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Male" & group$Age_char2 == "Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table11 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Female" & group$Age_char2 == "Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table12 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))




group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Male" & group$Age_char2 == "Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table13 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- rbind(subset(pd,Exe_pattern == "Continuous exercise/One bout exercise after adaptive training"),
               subset(pd,Group == "Sedentary" & Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Female" & group$Age_char2 == "Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table14 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Continuouse exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))



group <- subset(pd,!(Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Female" & group$Age_char2 == "Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table15 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,!(Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Male" & group$Age_char2 == "Old")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table16 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


group <- subset(pd,!(Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Female" & group$Age_char2 == "Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table17 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))

group <- subset(pd,!(Other_treatment == "Untrained"))
group <- subset(group,group$Gender == "Male" & group$Age_char2 == "Young adult")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table18 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "Exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))





exp <- get(c("GSE163356_ncRNA","GSE106865_ncRNA","GSE28422_ncRNA","GSE224310_ncRNA")[4])
pd <- new.pd[colnames(exp),]

group <- subset(pd,Other_treatment == "Untrained")
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table19 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = unique(sub.exe$Exe_pattern),Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


group <- subset(pd,!(Other_treatment == "Untrained"))
exp1 <- exp[,rownames(group)]
group1 <- group$Group
deg <- DEG(EXP = exp1,GROUP = group1)
sub.exe <- subset(group,group$Group == "Exercise")
out.table20 <- data.frame(Gene_Symbol = rownames(deg),Average_expression = deg$AveExpr,logFC = deg$logFC,P.Value = deg$P.Value,adj.P.Value = deg$adj.P.Val,
                          Series_id = unique(sub.exe$Series_id),Tissue_char1 = unique(sub.exe$Tissue_char1),Tissue_char2 = unique(sub.exe$Tissue_char2),Age = unique(sub.exe$Age_char2),
                          Gender = unique(sub.exe$Gender),Health_condition = unique(sub.exe$Health_condition),BMI = unique(sub.exe$BMI_char2),
                          Exercise_pattern = "One bout exercise after adaptive exercise",Exercise_type = unique(sub.exe$Exe_Type),
                          Exercise_during = unique(sub.exe$Exe_Duration),Exercise_frequency = unique(sub.exe$Exe_Freq),
                          Exercise_time = unique(sub.exe$Exe_time),Exercise_intensity = unique(sub.exe$Exe_Intensity),Sampling_time = unique(sub.exe$Sampling_time))


for (i in 1:20) {
  nnn <- get(paste0("out.table",i))
  all.out.table <- rbind(all.out.table,nnn)
}

human.deg <- all.out.table
ncrna_human.pd <- rbind(ncrna_human.pd[unique(used.sample),],new.pd)

# save(ncrna_human.pd,file = "~/exedatabase_v1.5/ncrna_human_pd.RData")
# save(human.deg,file = "~/exedatabase_v1.5/ncrna_human_deg.RData")

```

