

```bash
#!/bin/bash
## Step 1: Download
prefetch "$1"
wait  # Wait for download to complete

# Step 2: fast_dump
sra_dir="/home/data/User/Sra/sra"

if [[ -e "$sra_dir/$1.sra" ]]; then
  echo "$1 SRA file $1.sra found."
  cd "$sra_dir"
  
  # If file exists, use parallel-fastq-dump to convert to Fastq format
  outputdir="/home/data/User/Sra/clean"
  parallel-fastq-dump -O $outputdir -t 8 --split-3 --gzip -s $1.sra
else
  echo "Error: SRA file "$1".sra not found."
fi

wait

# Define input and output directories
fq_input_dir='/home/data/User/Sra/clean'
fq_output_dir='/home/data/User/Sra/clean'
fq_error_dir='/home/data/User/Sra/error'  # Updated error directory address
sam_dir='/home/data/User/Sra/align'
   
if [[ -e "$fq_input_dir/$1.fastq.gz" ]]; then
  echo "$1.fastq.gz found"
  rm $sra_dir/$1.sra

  # Change to input directory
  cd "$fq_input_dir" || exit 

  # Trim sequences starting with --three_prime_clip_R1
  trim_galore -q 20 -j 48 --phred33 --length 20 --stringency 3 --trim-n --max_n 0.7 \
  -o "$fq_output_dir" "$1.fastq.gz"
  wait
else
  # If failed, move input file to error directory and output error message
  echo "$1.fastq.gz not found"
fi

if [[ -e "$fq_output_dir/$1_trimmed.fq.gz" ]]; then
  echo "$1_trimmed.fq.gz found"
  rm "$fq_output_dir/$1.fastq.gz" 
  #human $fq_output_dir/grch38/genome
  hisat2 -p 18 -x $fq_output_dir/gene/grcm38/genome -U "$1_trimmed.fq.gz" -S "$1.sam"  
  wait

  # Check if .sam file was successfully generated
  if [ -f "$1.sam" ]; then
    echo "$1.sam finished."

    # Move .sam file to specified directory
    mv "$1.sam" $sam_dir

    # Delete original file
    rm "$1_trimmed.fq.gz"
    
    echo "$1 finished hisat"
  else
    echo "Error: $1.sam not found. Moving .fq.gz files to error directory..."

    # Move original file to error directory
    mv "$1_trimmed.fq.gz" $fq_error_dir
  fi
else
  echo "$1_trimmed.fq.gz not found"
fi

# Define variables
samfile="/home/data/User/Sra/align/$1.sam"
bamfile="/home/data/User/Sra/align/$1.bam"

# Create directories
mkdir -p /home/data/User/Sra/samerro
mkdir -p /home/data/User/Sra/bamerro
samerrodir="/home/data/User/Sra/samerro"  # Replace with actual error directory path
bamerrodir="/home/data/User/Sra/bamerro"

# Check if .sam file exists
if [[ -e "$samfile" ]]; then
  echo "File exists."

  # Change to target directory
  cd "/home/data/User/Sra/align"

  # Convert .sam to .bam
  samtools view -S "$1.sam" -b > "$1.bam" 
  pid=$!
  wait $pid

  # Check if samtools command was successful
  if [[ $? -eq 0 && -e "$bamfile" ]]; then
    echo "$1.sam finished converting to $1.bam."
    rm "$1.sam"
  else
    echo "$1.sam failed to convert to $1.bam."
    mv "$1.sam" "$samerrodir"
  fi
else
  echo "$1.sam not found."
fi

if [[ -e "$bamfile" ]]; then
  echo "File exists."

  # Change to target directory
  cd "/home/data/User/Sra/align"

  # Convert .sam to .bam
  samtools sort -o $1_sort.bam $1.bam
  pid=$!
  wait $pid

  # Check if samtools command was successful
  if [[ $? -eq 0 && -e "$bamfile" ]]; then
    echo "$1.bam finished converting to $1_sort.bam."
    rm "$1.bam"
  else
    echo "$1.bam failed to convert to $1_sort.bam."
    mv "$1.bam" "$bamerrodir"
  fi
else
  echo "$1.bam not found."
fi


```

```bash
#!/bin/bash
## Step 1: Download
prefetch "$1" 
wait  # Wait for download to complete

# Step 2: fast_dump
sra_dir="/home/data/User/Sra/sra"

if [[ -e "$sra_dir/$1.sra" ]]; then
  echo "$1 SRA file $1.sra found."
  cd "$sra_dir"
  
  # If file exists, use parallel-fastq-dump to convert to Fastq format
  outputdir="/home/data/User/Sra/clean"
  parallel-fastq-dump -O $outputdir -t 8 --split-3 --gzip -s $1.sra
else
  echo "Error: SRA file "$1".sra not found."
fi

wait

# Define input and output directories
fq_input_dir='/home/data/User/Sra/clean'
fq_output_dir='/home/data/User/Sra/clean'
fq_error_dir='/home/data/User/Sra/error'  # Updated error directory address
sam_dir='/home/data/User/Sra/align'
   
if [[ -e "$fq_input_dir/$1_1.fastq.gz" && -e "$fq_input_dir/$1_2.fastq.gz" ]]; then
  echo "$1_1.fastq.gz $1_2.fastq.gz found"

  # Change to input directory
  cd "$fq_input_dir" || exit 

  # Trim sequences starting with --three_prime_clip_R1
  trim_galore -q 20 -j 48 --phred33 --length 20 --stringency 3 --trim-n --max_n 0.7 --paired \
  -o "$fq_output_dir" "$1_1.fastq.gz" "$1_2.fastq.gz"
  wait
else
  # If failed, move input files to error directory and output error message
  echo "$1_1.fastq.gz $1_2.fastq.gz not found"
fi

if [[ -e "$fq_input_dir/$1_1_val_1.fq.gz" && -e "$fq_input_dir/$1_2_val_2.fq.gz" ]]; then
  echo "$1_1_val_1.fq.gz $1_2_val_2.fq.gz found"
  rm "$fq_input_dir/$1_1.fastq.gz" "$fq_input_dir/$1_2.fastq.gz" 

  # Align reads using HISAT2
  hisat2 -p 8 -x $fq_output_dir/gene/grcm38/genome -1 "$1_1_val_1.fq.gz" -2 "$1_2_val_2.fq.gz" -S "$1.sam"
  wait

  # Check if .sam file was generated successfully
  if [ -f "$1.sam" ]; then
    echo "$1.sam finished."

    # Move .sam file to specified directory
    mv "$1.sam" $sam_dir

    # Delete original files
    rm "$1_1_val_1.fq.gz" "$1_2_val_2.fq.gz"
    
    echo "$1 finished hisat"
  else
    echo "Error: $1.sam not found. Moving .fq.gz files to error directory..."

    # Move original files to error directory
    mv "$1_1_val_1.fq.gz" $fq_error_dir
    mv "$1_2_val_2.fq.gz" $fq_error_dir
  fi
else
  echo "$1_1_val_1.fq.gz $1_2_val_2.fq.gz not found"
fi

# Define variables
samfile="/home/data/User/Sra/align/$1.sam"
bamfile="/home/data/User/Sra/align/$1.bam"

# Create directories
mkdir -p /home/data/User/Sra/samerro
mkdir -p /home/data/User/Sra/bamerro
samerrodir="/home/data/User/Sra/samerro"  # Replace with actual error directory path
bamerrodir="/home/data/User/Sra/bamerro"

# Check if .sam file exists
if [[ -e "$samfile" ]]; then
  echo "File exists."

  # Change to target directory
  cd "/home/data/User/Sra/align"

  # Convert .sam to .bam
  samtools view -S "$1.sam" -b > "$1.bam" 
  pid=$!
  wait $pid

  # Check if samtools command was successful
  if [[ $? -eq 0 && -e "$bamfile" ]]; then
    echo "$1.sam finished converting to $1.bam."
    rm "$1.sam"
  else
    echo "$1.sam failed to convert to $1.bam."
    mv "$1.sam" "$samerrodir"
  fi
else
  echo "$1.sam not found."
fi

# Check if .bam file exists
if [[ -e "$bamfile" ]]; then
  echo "File exists."

  # Change to target directory
  cd "/home/data/User/Sra/align"

  # Sort .bam file
  samtools sort -o $1_sort.bam $1.bam
  pid=$!
  wait $pid

  # Check if samtools command was successful
  if [[ $? -eq 0 && -e "$bamfile" ]]; then
    echo "$1.bam finished converting to $1_sort.bam."
    rm "$1.bam"
  else
    echo "$1.bam failed to convert to $1_sort.bam."
    mv "$1.bam" "$bamerrodir"
  fi
else
  echo "$1.bam not found."
fi


```

```bash
# Run the script
var1=$1
var2=$2

# 使用拼接操作符将它们合并成一个新的变量
concatenated="${var1}${var2}"
echo "now deal with: ${concatenated}"
cat ${concatenated}|while read i
do 
echo $i
bash PE_allprocess $i
done
echo "all finish"




```



# featurecounts 

```bash
#human Homo_sapiens.GRCh38.109.gtf.gz
featureCounts -T 8 -a /home/data/User/Sra/align/gene/Mus_musculus.GRCm38.102.gtf.gz -g gene_id -p -o counts1.txt -t exon /home/data/User/Sra/align/*_sort.bam
```



